# Documentation Localization

The documentation is localized using [sphinx-intl](https://github.com/sphinx-doc/sphinx-intl),
and the translation files are placed in the [abqpy-locale](https://github.com/haiiliin/abqpy-locale) repository.
The translation takes place at [Crowdin](https://crowdin.com/project/abqpy-locale),
if you would like to help translate the documentation, please visit the
[Crowdin project](https://crowdin.com/project/abqpy-locale) and sign up for an
account. Once you have an account, you can request to join the translation team.

To add a new language, please open an issue on the [GitHub repository](https://github.com/haiiliin/abqpy/issues)
or open a pull request with the new language code added to the
[`docs/update-locale.sh`](https://github.com/haiiliin/abqpy/blob/main/docs/update-locale.sh) script.

## Comments

<script
   type="text/javascript"
   src="https://utteranc.es/client.js"
   async="async"
   repo="haiiliin/abqpy"
   issue-term="pathname"
   theme="github-light"
   label="💬 comment"
   crossorigin="anonymous"
/>
